@@ -107,6 +107,14 @@ public:
      */
     bool isRedoStackEmpty() const;
 
+   /**
+     * Returns whether or not events are being compressed for multiple
+     * markings. Applications doing custom multiple marking loops can
+     * use this function to check whether or not to perform post-marking
+     * code.
+
+     * @since 1.3
+     */
     bool areEventsCompressed() const;
 
     /**
@@ -369,6 +377,17 @@ public:
      */
     bool isBroken() const;
 
+   /**
+    * Returns the last time the APT repository sources have been refreshed/checked
+    * for updates. (Either with updateCache() or externally via other tools
+    * like apt-get)
+    *
+    * @returns @c QDateTime The time that the cache was last checked for updates.
+    * If this cannot be determined, an invalid QDateTime will be returned,
+    * which can be checked with QDateTime::isValid()
+    */
+    QDateTime timeCacheLastUpdated() const;
+
 protected:
     BackendPrivate *const d_ptr;
 
@@ -578,8 +597,24 @@ public Q_SLOTS:
      */
     void markPackageForRemoval(const QString &name);
 
+    /**
+     * Marks multiple packages at once. This is more efficient than marking
+     * packages individually, as event compression is utilized to prevent
+     * post-marking calculations from being performed until after all packages
+     * have been marked.
+     *
+     * @param packages The list of packages to be marked
+     * @param action The action to perform on the list of packages
+     *
+     * @since 1.3
+     */
     void markPackages(const QApt::PackageList &packages, QApt::Package::State action);
 
+    /**
+     * Manual control for enabling/disabling event compression. Useful for when
+     * an application needs to have its own multiple marking loop, but still wants
+     * to utilize event compression
+     */
     void setCompressEvents(bool enabled);
 
     /**
