@@ -39,6 +39,9 @@ namespace QApt {
  */
 class HistoryItemPrivate;
 
+// TODO QApt2: Rework private classes to derive from QSharedData, like the Changelog
+// Class does
+
 /**
  * The HistoryItem class represents a single entry in the APT history logs
  *
@@ -117,7 +120,7 @@ public:
     bool isValid() const;
 
 private:
-    Q_DECLARE_PRIVATE(HistoryItem);
+    Q_DECLARE_PRIVATE(HistoryItem)
     HistoryItemPrivate *const d_ptr;
 };
 
@@ -154,7 +157,7 @@ public:
     HistoryItemList historyItems() const;
 
 private:
-    Q_DECLARE_PRIVATE(History);
+    Q_DECLARE_PRIVATE(History)
     HistoryPrivate *const d_ptr;
 
 public Q_SLOTS:
